@@ -1,5 +1,9 @@
 #include "spu_callback.h"
+#ifdef MAEMO_CHANGES
+#include "maemo.h"
+#else
 #include <minimal.h>
+#endif
 
 
 extern void SoundFeedStreamData(unsigned char* pSound,long lBytes);
